@@ -1,13 +1,13 @@
 static const char *petscmachineinfo = "\n"
 "-----------------------------------------\n"
-"Libraries compiled on 2025-12-17 13:14:33 on reproducible\n"
+"Libraries compiled on 2026-01-24 13:32:28 on reproducible\n"
 "Machine characteristics: Linux-6.11.0-1018-azure-x86_64-with-glibc2.42\n"
 "Using PETSc directory: /opt/petsc/linux-c-opt\n"
 "Using PETSc arch: \n"
 "-----------------------------------------\n";
 static const char *petsccompilerinfo = "\n"
-"Using C compiler: /usr/bin/mpicc -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -flto=auto -fPIC \n"
-"Using Fortran compiler: /usr/bin/mpif90 -march=x86-64 -mtune=generic -O2 -pipe -fno-plt         -Wp,-D_FORTIFY_SOURCE=3 -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -fPIC   \n"
+"Using C compiler: /usr/bin/mpicc  -fPIC -Wall -Wwrite-strings -Wno-unknown-pragmas -Wno-lto-type-mismatch -Wno-stringop-overflow -fstack-protector -fvisibility=hidden -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -flto=auto \n"
+"Using Fortran compiler: /usr/bin/mpif90  -fPIC -Wall -ffree-line-length-none -ffree-line-length-0 -Wno-lto-type-mismatch -Wno-unused-dummy-argument -march=x86-64 -mtune=generic -O2 -pipe -fno-plt         -Wp,-D_FORTIFY_SOURCE=3 -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer   \n"
 "-----------------------------------------\n";
 static const char *petsccompilerflagsinfo = "\n"
 "Using include paths: -I/opt/petsc/linux-c-opt/include -I/usr/include/hypre -I/usr/include/suitesparse -I/usr/include -I/usr/include/superlu_dist -I/usr/include/superlu\n"
